@@ -4,7 +4,7 @@
 
 ;; Author: Hugo Thunnissen <devel@hugot.nl>
 ;; Keywords: php, languages, tools, convenience
-;; Version: 2.0.0
+;; Version: 2.0.1
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -386,12 +386,12 @@ that there are import (\"use\") statements for them."
             (unless token-meta
               (error "Unable to find token for namespace %s" namespace-name))
 
-	    (when phpinspect-imports-remove-unused
-              (phpinspect-add-use-statements-for-missing-types
-               used-types buffer (append imports namespace-imports) project token-meta))
+            (phpinspect-add-use-statements-for-missing-types
+             used-types buffer (append imports namespace-imports) project token-meta)
 
-            ;; (phpinspect-remove-unneeded-use-statements
-            ;;  used-types buffer (append imports namespace-imports) token-meta)
+	    (when phpinspect-imports-remove-unused
+              (phpinspect-remove-unneeded-use-statements
+               used-types buffer (append imports namespace-imports) token-meta))
 
             (let ((parent (phpinspect-meta-find-parent-matching-token
                            token-meta #'phpinspect-namespace-or-root-p)))
